searchData={"items":[{"type":"module","title":"HTTPSpec","doc":"Provides implementation-independent HTTP-related structs.","ref":"HTTPSpec.html"},{"type":"module","title":"Why? - HTTPSpec","doc":"Almost every HTTP client has its own abstractions for request and response.\nThese abstractions are enough when solving problems with a particular HTTP\nclient. But, when you are building a package involving HTTP and do not want\nto be tied to a specific HTTP client, these abstractions become limiting.\n\nHTTP clients come and go, but HTTP standards endure forever. It's better to\nbuild around something that is almost unchanging, rather than something\nthat frequently changes.\n\nThis package try to provide implementation-independent HTTP-related structs.\nWith these structs, you can build things involving HTTP, but no actual HTTP\nrequest-response handling is required.","ref":"HTTPSpec.html#module-why"},{"type":"module","title":"Structs - HTTPSpec","doc":"* `HTTPSpec.Request`\n  * `HTTPSpec.Response`","ref":"HTTPSpec.html#module-structs"},{"type":"module","title":"Usage - HTTPSpec","doc":"Build a request struct:\n\n    HTTPSpec.Request.new(options)\n    HTTPSpec.Request.new!(options)\n\nBuild a response struct:\n\n    HTTPSpec.Response.new(options)\n    HTTPSpec.Response.new!(options)\n\nCheck out their docs for more available functionalities.","ref":"HTTPSpec.html#module-usage"},{"type":"type","title":"HTTPSpec.field/0","doc":"","ref":"HTTPSpec.html#t:field/0"},{"type":"type","title":"HTTPSpec.message/0","doc":"","ref":"HTTPSpec.html#t:message/0"},{"type":"module","title":"HTTPSpec.Request","doc":"A struct for describing HTTP requests.","ref":"HTTPSpec.Request.html"},{"type":"function","title":"HTTPSpec.Request.build_method/1","doc":"Builds a method.","ref":"HTTPSpec.Request.html#build_method/1"},{"type":"function","title":"Examples - HTTPSpec.Request.build_method/1","doc":"iex> request = HTTPSpec.Request.new!([method: :post, ...])\n    iex> HTTPSpec.Request.build_method(request)\n    \"POST\"\n\n    iex> request = HTTPSpec.Request.new!(method: \"POST\", ...)\n    iex> HTTPSpec.Request.build_method(request)\n    \"POST\"","ref":"HTTPSpec.Request.html#build_method/1-examples"},{"type":"function","title":"HTTPSpec.Request.build_url/1","doc":"Builds an URL.","ref":"HTTPSpec.Request.html#build_url/1"},{"type":"function","title":"Examples - HTTPSpec.Request.build_url/1","doc":"iex> request = HTTPSpec.Request.new!(\n    ...>   method: :get\n    ...>   scheme: :https,\n    ...>   host: \"www.example.com\",\n    ...>   port: 443,\n    ...>   path: \"/image.png\",\n    ...>   query: \"size=lg\",\n    ...>   fragment: \"124,28\"\n    ...> )\n    iex> HTTPSpec.Request.build_url(request)\n    \"https://www.example.com/image.png?size=lg#124,28\"","ref":"HTTPSpec.Request.html#build_url/1-examples"},{"type":"function","title":"HTTPSpec.Request.new/1","doc":"Creates a request from given options.\n\nThe options can be provided as a keyword list or a map.","ref":"HTTPSpec.Request.html#new/1"},{"type":"function","title":"Examples - HTTPSpec.Request.new/1","doc":"HTTPSpec.Request.new(%{\n      method: :post,\n      scheme: :https,\n      host: \"www.example.com\",\n      port: 443,\n      path: \"/talk\",\n      headers: [\n        {\"content-type\", \"application/x-www-form-urlencoded\"},\n        {\"accept\", \"text/html\"}\n      ],\n      body: \"say=Hi&to=Mom\",\n      query: \"tone=cute\"\n    })\n\nAnd, an `url` option is provided for setting `scheme`, `host`, `port`, `path`\nand `query` in a quick way.\n\n    HTTPSpec.Request.new(%{\n      method: :post,\n      url: \"https://www.example.com/talk?tone=cute\",\n      headers: [\n        {\"content-type\", \"application/x-www-form-urlencoded\"},\n        {\"accept\", \"text/html\"}\n      ],\n      body: \"say=Hi&to=Mom\"\n    })","ref":"HTTPSpec.Request.html#new/1-examples"},{"type":"function","title":"HTTPSpec.Request.new!/1","doc":"Bang version of `new/1`.","ref":"HTTPSpec.Request.html#new!/1"},{"type":"function","title":"HTTPSpec.Request.put_body/2","doc":"Puts body into request.","ref":"HTTPSpec.Request.html#put_body/2"},{"type":"function","title":"HTTPSpec.Request.put_query/2","doc":"Puts query into request.","ref":"HTTPSpec.Request.html#put_query/2"},{"type":"type","title":"HTTPSpec.Request.body/0","doc":"","ref":"HTTPSpec.Request.html#t:body/0"},{"type":"type","title":"HTTPSpec.Request.fragment/0","doc":"","ref":"HTTPSpec.Request.html#t:fragment/0"},{"type":"type","title":"HTTPSpec.Request.host/0","doc":"","ref":"HTTPSpec.Request.html#t:host/0"},{"type":"type","title":"HTTPSpec.Request.method/0","doc":"","ref":"HTTPSpec.Request.html#t:method/0"},{"type":"type","title":"HTTPSpec.Request.path/0","doc":"","ref":"HTTPSpec.Request.html#t:path/0"},{"type":"type","title":"HTTPSpec.Request.query/0","doc":"","ref":"HTTPSpec.Request.html#t:query/0"},{"type":"type","title":"HTTPSpec.Request.scheme/0","doc":"","ref":"HTTPSpec.Request.html#t:scheme/0"},{"type":"type","title":"HTTPSpec.Request.t/0","doc":"","ref":"HTTPSpec.Request.html#t:t/0"},{"type":"type","title":"HTTPSpec.Request.url/0","doc":"","ref":"HTTPSpec.Request.html#t:url/0"},{"type":"module","title":"HTTPSpec.Request.QueryParams","doc":"Helpers for handling key-value pairs which are encoded as query.\n\n> #### Note {: .info}\n> This module doesn't support Key-value pairs that contains duplicate keys,\n> because the underlying data structure is a map.\n\n> Because query doesn't always contain key-value pairs, so related helpers\n> are grouped as this extra module.","ref":"HTTPSpec.Request.QueryParams.html"},{"type":"function","title":"HTTPSpec.Request.QueryParams.decode/2","doc":"","ref":"HTTPSpec.Request.QueryParams.html#decode/2"},{"type":"function","title":"HTTPSpec.Request.QueryParams.delete/2","doc":"","ref":"HTTPSpec.Request.QueryParams.html#delete/2"},{"type":"function","title":"HTTPSpec.Request.QueryParams.encode/2","doc":"","ref":"HTTPSpec.Request.QueryParams.html#encode/2"},{"type":"function","title":"HTTPSpec.Request.QueryParams.get/3","doc":"","ref":"HTTPSpec.Request.QueryParams.html#get/3"},{"type":"function","title":"HTTPSpec.Request.QueryParams.new/1","doc":"","ref":"HTTPSpec.Request.QueryParams.html#new/1"},{"type":"function","title":"HTTPSpec.Request.QueryParams.put/3","doc":"","ref":"HTTPSpec.Request.QueryParams.html#put/3"},{"type":"function","title":"HTTPSpec.Request.QueryParams.put_new/3","doc":"","ref":"HTTPSpec.Request.QueryParams.html#put_new/3"},{"type":"function","title":"HTTPSpec.Request.QueryParams.put_new_lazy/3","doc":"","ref":"HTTPSpec.Request.QueryParams.html#put_new_lazy/3"},{"type":"type","title":"HTTPSpec.Request.QueryParams.encoding/0","doc":"","ref":"HTTPSpec.Request.QueryParams.html#t:encoding/0"},{"type":"type","title":"HTTPSpec.Request.QueryParams.name/0","doc":"","ref":"HTTPSpec.Request.QueryParams.html#t:name/0"},{"type":"type","title":"HTTPSpec.Request.QueryParams.t/0","doc":"","ref":"HTTPSpec.Request.QueryParams.html#t:t/0"},{"type":"type","title":"HTTPSpec.Request.QueryParams.value/0","doc":"","ref":"HTTPSpec.Request.QueryParams.html#t:value/0"},{"type":"module","title":"HTTPSpec.Request.URL","doc":"Helpers for handling URL.","ref":"HTTPSpec.Request.URL.html"},{"type":"function","title":"HTTPSpec.Request.URL.parse/1","doc":"Parses an URL.","ref":"HTTPSpec.Request.URL.html#parse/1"},{"type":"function","title":"Examples - HTTPSpec.Request.URL.parse/1","doc":"iex> HTTPSpec.Request.URL.parse(\"http://www.example.com/?say=hi#mom\")\n    {:ok,\n     %HTTPSpec.Request.URL{\n       scheme: :http,\n       host: \"www.example.com\",\n       port: 80,\n       path: \"/\",\n       query: \"say=hi\",\n       fragment: \"mom\"\n     }}","ref":"HTTPSpec.Request.URL.html#parse/1-examples"},{"type":"function","title":"HTTPSpec.Request.URL.parse!/1","doc":"Bang version of `parse/1`.","ref":"HTTPSpec.Request.URL.html#parse!/1"},{"type":"type","title":"HTTPSpec.Request.URL.t/0","doc":"","ref":"HTTPSpec.Request.URL.html#t:t/0"},{"type":"module","title":"HTTPSpec.Response","doc":"A struct for describing HTTP responses.","ref":"HTTPSpec.Response.html"},{"type":"function","title":"HTTPSpec.Response.new/1","doc":"Creates a response from given options.\n\nThe options can be provided as a keyword list or a map.","ref":"HTTPSpec.Response.html#new/1"},{"type":"function","title":"Examples - HTTPSpec.Response.new/1","doc":"HTTPSpec.Response.new(%{\n      status: 200,\n      headers: [\n        {\"content-type\", \"text/html\"}\n      ],\n      body: \" ... \"\n    })","ref":"HTTPSpec.Response.html#new/1-examples"},{"type":"function","title":"HTTPSpec.Response.new!/1","doc":"Bang version of `new/1`.","ref":"HTTPSpec.Response.html#new!/1"},{"type":"type","title":"HTTPSpec.Response.body/0","doc":"","ref":"HTTPSpec.Response.html#t:body/0"},{"type":"type","title":"HTTPSpec.Response.status/0","doc":"","ref":"HTTPSpec.Response.html#t:status/0"},{"type":"type","title":"HTTPSpec.Response.t/0","doc":"","ref":"HTTPSpec.Response.html#t:t/0"},{"type":"module","title":"HTTPSpec.Header","doc":"Helpers for handling headers.","ref":"HTTPSpec.Header.html"},{"type":"function","title":"HTTPSpec.Header.delete_header/2","doc":"Deletes the header given by `name`.\n\nAll occurrences of the header are deleted, in case the header is repeated multiple times.","ref":"HTTPSpec.Header.html#delete_header/2"},{"type":"function","title":"Examples - HTTPSpec.Header.delete_header/2","doc":"iex> HTTPSpec.Header.get_header(request, \"cache-control\")\n    [\"max-age=600\", \"no-transform\"]\n    iex> request = Request.delete_header(req, \"cache-control\")\n    iex> HTTPSpec.Header.get_header(request, \"cache-control\")\n    []","ref":"HTTPSpec.Header.html#delete_header/2-examples"},{"type":"function","title":"HTTPSpec.Header.get_header/2","doc":"Returns the values of the header specified by `name`.","ref":"HTTPSpec.Header.html#get_header/2"},{"type":"function","title":"Examples - HTTPSpec.Header.get_header/2","doc":"iex> HTTPSpec.Header.get_header(request, \"accept\")\n    [\"application/json\"]\n    iex> HTTPSpec.Header.get_header(requset, \"x-unknown\")\n    []","ref":"HTTPSpec.Header.html#get_header/2-examples"},{"type":"function","title":"HTTPSpec.Header.put_header/3","doc":"Puts the given `value` under `name`.\n\nIf the header was previously set, its value is overwritten.","ref":"HTTPSpec.Header.html#put_header/3"},{"type":"function","title":"Examples - HTTPSpec.Header.put_header/3","doc":"iex> HTTPSpec.Header.get_header(request, \"accept\")\n    []\n    iex> request = Request.put_header(request, \"accept\", \"application/json\")\n    iex> HTTPSpec.Header.get_header(request, \"accept\")\n    [\"application/json\"]","ref":"HTTPSpec.Header.html#put_header/3-examples"},{"type":"function","title":"HTTPSpec.Header.put_new_header/3","doc":"Puts the given `value` under `name` unless already present.\n\nSee `put_header/3` for more information.","ref":"HTTPSpec.Header.html#put_new_header/3"},{"type":"function","title":"Examples - HTTPSpec.Header.put_new_header/3","doc":"iex> request =\n    ...>   request\n    ...>   |> HTTPSpec.Header.put_new_header(\"accept\", \"application/json\")\n    ...>   |> HTTPSpec.Header.put_new_header(\"accept\", \"text/html\")\n    iex> HTTPSpec.Header.get_header(request, \"accept\")\n    [\"application/json\"]","ref":"HTTPSpec.Header.html#put_new_header/3-examples"},{"type":"function","title":"HTTPSpec.Header.put_new_lazy_header/3","doc":"Lazy version of `put_new_header/3`.","ref":"HTTPSpec.Header.html#put_new_lazy_header/3"},{"type":"type","title":"HTTPSpec.Header.headers/0","doc":"","ref":"HTTPSpec.Header.html#t:headers/0"},{"type":"module","title":"HTTPSpec.Trailer","doc":"Helpers for handling trailers.\n\n> #### Note {: .info}\n> Currently, I don't have this requirement. PRs are welcome.","ref":"HTTPSpec.Trailer.html"},{"type":"type","title":"HTTPSpec.Trailer.trailers/0","doc":"","ref":"HTTPSpec.Trailer.html#t:trailers/0"},{"type":"exception","title":"HTTPSpec.ArgumentError","doc":"An error that is returned (or raised) when given options are invalid.","ref":"HTTPSpec.ArgumentError.html"},{"type":"type","title":"HTTPSpec.ArgumentError.t/0","doc":"","ref":"HTTPSpec.ArgumentError.html#t:t/0"},{"type":"exception","title":"HTTPSpec.Request.URL.ParseError","doc":"An error that is returned (or raised) when failed to parse a string as URL.","ref":"HTTPSpec.Request.URL.ParseError.html"},{"type":"type","title":"HTTPSpec.Request.URL.ParseError.t/0","doc":"","ref":"HTTPSpec.Request.URL.ParseError.html#t:t/0"},{"type":"extras","title":"HTTPSpec","doc":"# HTTPSpec\n\n[![CI](https://github.com/cozy-elixir/http_spec/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/http_spec/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/http_spec.svg)](https://hex.pm/packages/http_spec)\n\nProvides implementation-independent HTTP-related structs.","ref":"readme.html"},{"type":"extras","title":"Installation - HTTPSpec","doc":"Add `:http_spec` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:http_spec,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HTTPSpec","doc":"For more information, see the [documentation](https://hexdocs.pm/http_spec).","ref":"readme.html#usage"},{"type":"extras","title":"Thanks - HTTPSpec","doc":"- [wojtekmach/req](https://github.com/wojtekmach/req)\n- [inets/httpc from Erlang](https://www.erlang.org/doc/apps/inets/httpc)","ref":"readme.html#thanks"},{"type":"extras","title":"License - HTTPSpec","doc":"[Apache License 2.0](http://www.apache.org/licenses/LICENSE-2.0)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v3.0.0 - Changelog","doc":"- rename `HTTPSpec.Request.Query` to `HTTPSpec.Request.QueryParams`.\n- change default encoding of of `HTTPSpec.Request.QueryParams` to `:rfc3986`.\n- rename `HTTPSpec.Request.URL.parse/1` to `HTTPSpec.Request.URL.parse!/1`\n- add new `HTTPSpec.Request.URL.parse/1` which returns ok/error tuple.\n- move all header related function to a new module `HTTPSpec.Header`\n- move all trailer related function to a new module `HTTPSpec.Trailer`","ref":"changelog.html#v3-0-0"},{"type":"extras","title":"v2.3.0 - Changelog","doc":"- add `:url` option for `HTTPSpec.Request.new/1` and `HTTPSpec.Request.new!/1`","ref":"changelog.html#v2-3-0"},{"type":"extras","title":"v2.2.0 - Changelog","doc":"- add `HTTPSpec.Request.URL`","ref":"changelog.html#v2-2-0"},{"type":"extras","title":"v2.1.0 - Changelog","doc":"- add `HTTPSpec.Request.put_query/2`\n- add `HTTPSpec.Request.put_new_header/3`\n- add `HTTPSpec.Request.put_new_lazy_header/3`\n- add `HTTPSpec.Request.put_body/2`\n- add `HTTPSpec.Request.Query`","ref":"changelog.html#v2-1-0"},{"type":"extras","title":"v2.0.0 - Changelog","doc":"","ref":"changelog.html#v2-0-0"},{"type":"extras","title":"vBreaking changes - Changelog","doc":"- rename `build/1` to `new/1`\n- rename `build!/1` to `new!/1`\n- downcase header names when building a `%HTTPSpec.Response{}`","ref":"changelog.html#vbreaking-changes"},{"type":"extras","title":"vNew features - Changelog","doc":"- add `HTTPSpec.Request.build_method/1`\n- add `HTTPSpec.Request.build_url/1`\n- add `HTTPSpec.Response.get_trailer/2`","ref":"changelog.html#vnew-features"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}